==> binder_trace-1.1.0-py3-none-any.whl: binder_trace/tui/widget/help.py <==
from prompt_toolkit.layout import AnyContainer, HSplit, VSplit
from prompt_toolkit.widgets import Box, Frame, Label


class HelpPanel:
    def __init__(self) -> None:
        self.visible = False

        float_frame = Box(
            padding_top=1,
            padding_left=2,
            padding_right=2,
            body=HSplit(
                children=[
                    Label(f"{'-'*20}Gerneral{'-'*27}"),
                    Label("up             Move up"),
                    Label("down           Move down"),
                    Label("shift + up     Page up"),
                    Label("shift + down   Page down"),
                    Label("home           Go to top"),
                    Label("end            Go to bottom"),
                    Label("tab            Next pane"),
                    Label("shift + tab    Previous pane"),
                    Label("ctrl + c       Copy pane to clipboard"),
                    Label("f              Open filter options"),
                    Label("space          Pause/Unpause transaction recording"),
                    Label("c              Clear"),
                    Label("h              Help"),
                    Label("q              Quit"),
                    Label(f"{'-'*20}Frequency Frame{'-'*20}"),
                    Label("p              Toggle order asc/desc"),
                    Label("w              Jump to next interface"),
                    Label("s              Jump to previous interface"),
                    Label("enter          Toggle Filter"),
                ]
            ),
        )

        self.container = Frame(
            title="Help",
            body=float_frame,
            style="class:dialog.background",
            modal=True,
        )

    def __pt_container__(self) -> AnyContainer:
        return self.container

==> binder_trace-1.3.2-py3-none-any.whl: binder_trace/tui/widget/help.py <==
from prompt_toolkit.layout import AnyContainer, HSplit, VSplit
from prompt_toolkit.widgets import Box, Frame, Label


class HelpPanel:
    def __init__(self) -> None:
        self.visible = False

        float_frame = Box(
            padding_top=1,
            padding_left=2,
            padding_right=2,
            body=HSplit(
                children=[
                    Label(f"{'-'*20}General{'-'*27}"),
                    Label("up             Move up"),
                    Label("down           Move down"),
                    Label("shift + up     Page up"),
                    Label("shift + down   Page down"),
                    Label("home           Go to top"),
                    Label("end            Go to bottom"),
                    Label("tab            Next pane"),
                    Label("shift + tab    Previous pane"),
                    Label("ctrl + c       Copy pane to clipboard"),
                    Label("space          Pause/Unpause transaction recording"),
                    Label("c              Clear"),
                    Label("h              Help"),
                    Label("q              Quit"),
                    Label(f"{'-'*20}Frequency Frame{'-'*20}"),
                    Label("p              Toggle order asc/desc"),
                    Label("w              Jump to next interface"),
                    Label("s              Jump to previous interface"),
                    Label("a              Toggle all filters on"),
                    Label("n              Toggle all filters off"),
                    Label("enter          Toggle Filter"),
                ]
            ),
        )

        self.container = Frame(
            title="Help",
            body=float_frame,
            style="class:dialog.background",
            modal=True,
        )

    def __pt_container__(self) -> AnyContainer:
        return self.container
